# custom colormaps

[![PyPI](https://img.shields.io/pypi/v/demonstration.svg?label=PyPI&style=flat-square)](https://pypi.org/project/demonstration/)
[![Python](https://img.shields.io/pypi/pyversions/demonstration.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/project/demonstration/)
[![Test](https://img.shields.io/github/workflow/status/astropenguin/python-package-template/Test?logo=github&label=Test&style=flat-square)](https://github.com/astropenguin/python-package-template/actions)
[![License](https://img.shields.io/badge/license-MIT-blue.svg?label=License&style=flat-square)](LICENSE)

This package is a simple extension of matplotlib's colormaps with particular focus on the visualization of radio astronomical maps.
